Welcome to ClientVPS Mirrors

Help for package fdq
Type: Package
Title: Forest Data Quality
Version: 0.12
Maintainer: Caíque de Oliveira de Souza <forestgrowthsoftware@gmail.com>
Description: Forest data quality is a package containing nine methods of analysis for forest databases, from databases containing inventory data and growth models, the focus of the analyzes is related to the quality of the data present in the database with a focus on consistency , punctuality and completeness of data.
License: GPL-3
Encoding: UTF-8
LazyData: true
Depends: Fgmutils (≥ 0.8), R (≥ 3.0)
Imports: data.table, sqldf, randomcoloR, ggplot2
NeedsCompilation: no
Packaged: 2021-01-27 12:24:46 UTC; conta
Author: Caíque de Oliveira de Souza [aut, cre], Clayton Vieira Fraga Filho [ctb, dtc], Gilson Fernandes da Silva [ctb, dtc], Miquéias Fernandes [ctb]
Repository: CRAN
Date/Publication: 2021-01-28 05:40:03 UTC

Hello, World!

Description

Prints 'Hello, world!'.

Usage

hello()

Examples

hello()

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.